@@ -83,9 +83,10 @@ IPv6address = Group(Or([
                   ])).setResultsName("IPv6address")
 IP_literal = Group(
                    Literal("[") + Or([IPv6address, IPvFuture]) + Literal("]")
-                   )
+                   ).setResultsName("IP_literal")
 reg_name = Combine(ZeroOrMore(unreserved ^ pct_encoded ^ sub_delims))
-host = Group(IP_literal ^ IPv4address ^ reg_name).setResultsName("host")
+host = IP_literal ^ IPv4address ^ reg_name
+host.setResultsName("host")
 
 port = Number.setResultsName("port")
 authority = Group(
@@ -102,7 +103,7 @@ path_noscheme = segment_nz_nc + ZeroOrMore(sepSegment)
 path_empty = Literal("")
 
 hier_part = Group(
-            Literal("//") + authority + path_abempty ^ \
+            Group(Literal("//") + authority + path_abempty) ^ \
             path_absolute ^ \
             path_noscheme ^ \
             path_empty
